@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2007 Michal Čihař
+ * Copyright © 2003 - 2008 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -176,7 +176,7 @@ PyObject *FileToPython(GSM_File *file) {
 int FileFromPython(PyObject *dict, GSM_File *file, bool check) {
     char            *s;
     GSM_DateTime    nulldt = {0,0,0,0,0,0,0};
-    int             i;
+    Py_ssize_t      i;
 
     if (!PyDict_Check(dict)) {
         PyErr_Format(PyExc_ValueError, "File is not a dictionary");
@@ -250,7 +250,7 @@ int FileFromPython(PyObject *dict, GSM_File *file, bool check) {
         if (file->Used == INT_INVALID) {
             file->Used = i;
         } else if (file->Used != i) {
-            PyErr_Format(PyExc_ValueError, "Used and Buffer size mismatch in File (%zi != %i)!", file->Used, i);
+            PyErr_Format(PyExc_ValueError, "Used and Buffer size mismatch in File (%zi != %zi)!", file->Used, i);
             return 0;
         }
         file->Buffer = (unsigned char *)malloc(i * sizeof(unsigned char));
