@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2007 Michal Čihař
+ * Copyright © 2003 - 2008 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -532,6 +532,7 @@ char *SMSStateToString(GSM_SMS_State type) {
 
 int UDHFromPython(PyObject *dict, GSM_UDHHeader *udh) {
     char *s;
+    Py_ssize_t len;
 
     if (!PyDict_Check(dict)) {
         PyErr_Format(PyExc_ValueError, "UDH is not a dictionary");
@@ -569,9 +570,11 @@ int UDHFromPython(PyObject *dict, GSM_UDHHeader *udh) {
     udh->Type = StringToUDHType(s);
     if (udh->Type == 0) return 0;
 
-    s = GetDataFromDict(dict, "Text", &(udh->Length));
+    s = GetDataFromDict(dict, "Text", &len);
     if (s == NULL) return 0;
 
+    udh->Length = len;
+
     if (udh->Length > GSM_MAX_UDH_LENGTH) {
         pyg_warning("UDH too large, truncating!");
         udh->Length = GSM_MAX_UDH_LENGTH;
@@ -607,6 +610,7 @@ int SMSFromPython(PyObject *dict, GSM_SMSMessage *sms, int needslocation, int ne
     char            *s;
     GSM_DateTime    nulldt = {0,0,0,0,0,0,0};
     int             i;
+    Py_ssize_t len;
 
     if (!PyDict_Check(dict)) {
         PyErr_Format(PyExc_ValueError, "SMS is not a dictionary");
@@ -670,9 +674,11 @@ int SMSFromPython(PyObject *dict, GSM_SMSMessage *sms, int needslocation, int ne
         sms->Length = UnicodeLength(sms->Text);
     } else {
         /* Some UDH => copy as data */
-        s = GetDataFromDict(dict, "Text", &(sms->Length));
+        s = GetDataFromDict(dict, "Text", &len);
         if (s == NULL) return 0;
 
+        sms->Length = len;
+
         if (sms->Length > GSM_MAX_SMS_LENGTH) {
             pyg_warning("SMS text too large, truncating!\n");
             sms->Length = GSM_MAX_SMS_LENGTH;
