@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2007 Michal Čihař
+ * Copyright © 2003 - 2008 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -83,6 +83,15 @@ PyObject *TodoToPython(const GSM_ToDoEntry *entry) {
                 f = Py_BuildValue("{s:s,s:O}", "Type", "END_DATETIME", "Value", d);
                 Py_DECREF(d);
                 break;
+            case TODO_START_DATETIME:
+                d = BuildPythonDateTime(&(entry->Entries[i].Date));
+                if (d == NULL) {
+                    Py_DECREF(v);
+                    return NULL;
+                }
+                f = Py_BuildValue("{s:s,s:O}", "Type", "START_DATETIME", "Value", d);
+                Py_DECREF(d);
+                break;
             case TODO_ALARM_DATETIME:
                 d = BuildPythonDateTime(&(entry->Entries[i].Date));
                 if (d == NULL) {
@@ -276,6 +285,9 @@ int TodoFromPython(PyObject *dict, GSM_ToDoEntry *entry, int needs_location) {
         if (strcmp("END_DATETIME", type) == 0) {
             valuetype = 'd';
             entry->Entries[i].EntryType = TODO_END_DATETIME;
+        } else if (strcmp("START_DATETIME", type) == 0) {
+            valuetype = 'd';
+            entry->Entries[i].EntryType = TODO_START_DATETIME;
         } else if (strcmp("COMPLETED", type) == 0) {
             valuetype = 'n';
             entry->Entries[i].EntryType = TODO_COMPLETED;
