@@ -11,26 +11,32 @@ sm = gammu.StateMachine()
 sm.ReadConfig()
 sm.Init()
 sm.SetIncomingCallback(Callback)
+
 try:
     sm.SetIncomingCall()
 except gammu.ERR_NOTSUPPORTED:
-    pass
+    print 'Incoming calls notification is not supported.'
+
 try:
     sm.SetIncomingCB()
 except gammu.ERR_NOTSUPPORTED:
-    pass
+    print 'Incoming CB notification is not supported.'
+except gammu.ERR_SOURCENOTAVAILABLE:
+    print 'Cell broadcasts support not enabled in Gammu.'
+
 try:
     sm.SetIncomingSMS()
 except gammu.ERR_NOTSUPPORTED:
-    pass
+    print 'Incoming SMS notification is not supported.'
+
 try:
     sm.SetIncomingUSSD()
 except gammu.ERR_NOTSUPPORTED:
-    pass
+    print 'Incoming USSD notification is not supported.'
 
 # We need to keep communication with phone to get notifications
 print 'Press Ctrl+C to interrupt'
 while 1:
-    time.sleep(1)
     q = sm.GetSignalQuality()
     print 'Signal is at %d%%' % q['SignalPercent']
+    time.sleep(1)
